aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyASICSignatureResponseType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyASICSignatureResponseType.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyASICSignatureResponseType.java68
1 files changed, 31 insertions, 37 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyASICSignatureResponseType.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyASICSignatureResponseType.java
index c58900b..4a72b62 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyASICSignatureResponseType.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyASICSignatureResponseType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,73 +10,67 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlElements;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlType;
/**
- * <p>Java class for VerifyASICSignatureResponseType complex type.
+ * <p>Java-Klasse für VerifyASICSignatureResponseType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="VerifyASICSignatureResponseType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence maxOccurs="unbounded">
- * &lt;element name="XMLSignatureResult" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}VerifyXMLSignatureResponseType" maxOccurs="unbounded" minOccurs="0"/>
- * &lt;element name="CMSSignatureResult" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}VerifyCMSSignatureResponseType" maxOccurs="unbounded" minOccurs="0"/>
- * &lt;/sequence>
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="VerifyASICSignatureResponseType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence&gt;
+ * &lt;element name="ASiCSignatureResult" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}ASICResultType" maxOccurs="unbounded" minOccurs="0"/&gt;
+ * &lt;/sequence&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
*/
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VerifyASICSignatureResponseType", propOrder = {
- "xmlSignatureResultAndCMSSignatureResult"
+ "aSiCSignatureResult"
})
public class VerifyASICSignatureResponseType {
- @XmlElements({
- @XmlElement(name = "XMLSignatureResult", type = VerifyXMLSignatureResponseType.class),
- @XmlElement(name = "CMSSignatureResult", type = VerifyCMSSignatureResponseType.class)
- })
- protected List<Object> xmlSignatureResultAndCMSSignatureResult;
+ @XmlElement(name = "ASiCSignatureResult")
+ protected List<ASICResultType> aSiCSignatureResult;
/**
* Gets the value of the xmlSignatureResultAndCMSSignatureResult property.
*
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the xmlSignatureResultAndCMSSignatureResult property.
*
* <p>
* For example, to add a new item, do as follows:
* <pre>
- * getXMLSignatureResultAndCMSSignatureResult().add(newItem);
+ * getASiCSignatureResult().add(newItem);
* </pre>
*
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link VerifyXMLSignatureResponseType }
- * {@link VerifyCMSSignatureResponseType }
+ * {@link ASICResultType }
*
*
*/
- public List<Object> getXMLSignatureResultAndCMSSignatureResult() {
- if (xmlSignatureResultAndCMSSignatureResult == null) {
- xmlSignatureResultAndCMSSignatureResult = new ArrayList<Object>();
+ public List<ASICResultType> getASiCSignatureResult() {
+ if (aSiCSignatureResult == null) {
+ aSiCSignatureResult = new ArrayList<ASICResultType>();
}
- return this.xmlSignatureResultAndCMSSignatureResult;
+ return this.aSiCSignatureResult;
}
}
@@ -10,73 +10,67 @@ package at.gv.egiz.moasig;
/**
- * Gets the value of the xmlSignatureResultAndCMSSignatureResult property.
+ * Gets the value of the aSiCSignatureResult property.
*
* <p>
@@ -10,73 +10,67 @@ package at.gv.egiz.moasig;
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
- * This is why there is not a <CODE>set</CODE> method for the xmlSignatureResultAndCMSSignatureResult property.
+ * returned list will be present inside the Jakarta XML Binding object.
+ * This is why there is not a <CODE>set</CODE> method for the aSiCSignatureResult property.
*
* <p>